import unittest, copy, os
import onkopus as op
import adagenes as ag

class MolFeatAnnotationTestCase(unittest.TestCase):

    def test_molfeat_client(self):
        #genome_version = 'hg19'
        genome_version = 'hg38'

        #data = {"chr17:7681744T>C": {}, "chr10:8115913C>T": {}}
        data = {"chr7:140753336A>T":{}}

        variant_data = op.UTAAdapterClient(genome_version=genome_version).process_data(data)
        #variant_data = op.MolecularFeaturesClient(
        #    genome_version=genome_version).process_data(variant_data)

        #print("Response ",variant_data)
        #self.assertEqual(variant_data["chr7:140753336A>T"]["molecular_features"]["aromaticity_alt"],0,"")

    def test_molfeat_export(self):
        genome_version = 'hg38'
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        infile = __location__ + "/../../test_files/somaticMutations.l520.protein.vcf"
        outfile = __location__ + "/../../test_files/somaticMutations.l520.protein.molfeat.vcf"

        data = {"chr7:140753336A>T": {}}

        #variant_data = op.UTAAdapterClient(genome_version=genome_version).process_data(data)
        magic_obj = op.MolecularFeaturesClient(
            genome_version=genome_version)
        #op.write_file(outfile, variant_data)

        ag.process_file(infile, outfile, magic_obj=magic_obj)

        file = open(outfile)
        contents = file.read()[0:60]
        contents_expected = """n"""
        #self.assertEqual(contents, contents_expected, "")
        file.close()




import unittest
import os
import onkopus as op
import adagenes as ag


class TestFullAnnotation(unittest.TestCase):

    def test_full_annotation(self):
        #data = {"TP53":{ }, "chr7:140753336A>T": {}, "NRAS:Q61L": {} }
        #bframe = adagenes.BiomarkerFrame()
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        #bframe = op.read_file(__location__ + "/../test_files/variants_grch38_20240206_Pathogenic_80.tsv")
        bframe = ag.BiomarkerFrame(["BRAF:V600E","TP53:R282W"])
        bframe.genome_version="hg38"
        #bframe.data = data

        bframe = op.annotate(bframe)

        #self.assertListEqual(list(bframe.data.keys()),["","chr7:140753336A>T",""],"IDs do not match")
        #print(bframe.data.keys())


        outfile_variants = __location__ + "/../test_files/clinvar_80.annotated.csv"
        outfile_treatments = __location__ + "/../test_files/clinvar_80.treatments.csv"

        op.save_variants(outfile_variants, bframe)
        op.save_treatments(outfile_treatments, bframe)

    def test_full_annotation_gene(self):
        #data = {"TP53":{ }, "chr7:140753336A>T": {}, "NRAS:Q61L": {} }
        #bframe = adagenes.BiomarkerFrame()
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        #bframe = op.read_file(__location__ + "/../test_files/variants_grch38_20240206_Pathogenic_80.tsv")
        bframe = ag.BiomarkerFrame(["TP53"])
        bframe.genome_version="hg38"
        #bframe.data = data
        print(bframe.data)

        bframe = op.annotate(bframe)

        self.assertEqual(list(bframe.data["TP53"].keys()), [
            'type',
            'mutation_type',
            'mdesc',
            'civic',
            'cosmic',
            'gencode',
            'onkopus_aggregator',
            'UTA_Adapter'
            ], "")




import unittest, os
import onkopus.onkopus_clients

class COSMICAnnotationTestCase(unittest.TestCase):

    def test_cosmic_client_snv(self):
        genome_version = 'hg38'

        data = {"chr7:140753336A>T": {}}

        variant_data = onkopus.UTAAdapterClient(genome_version=genome_version).process_data(data)
        variant_data = onkopus.onkopus_clients.COSMICGeneCensusClient(
            genome_version=genome_version).process_data(variant_data)

        print("Response ",variant_data)

    def test_cosmic_client_gene(self):
        genome_version = 'hg38'

        data = {"BRAF": {}}

        variant_data = onkopus.onkopus_clients.COSMICGeneCensusClient(
            genome_version=genome_version).process_data(data,gene_request=True)

        print("Response ",variant_data)



import datetime, traceback, copy
import adagenes.tools.parse_vcf
import adagenes.processing.parse_http_responses
from onkopus.conf import read_config as config
import adagenes.tools.module_requests as req
import onkopus as op

qid_key = "q_id"
error_logfile=None


class COSMICGeneCensusClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines = config.cosmic_info_lines
        self.url_pattern = config.cosmic_src
        self.srv_prefix = config.cosmic_srv_prefix
        self.extract_keys = config.cosmic_keys

        self.qid_key = "q_id"
        self.error_logfile = error_logfile
        #if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
        #    self.qid_key = "q_id_hg19"

    def process_data(self, vcf_lines,gene_request=False):

        # get gene names and variant exchange from passed JSON object
        #if input_format == 'vcf':
        #    keys = [config.uta_adapter_srv_prefix + config.concat_char + config.uta_genomic_keys[0],
        #            config.uta_adapter_srv_prefix + config.concat_char + config.uta_genomic_keys[1]]
        #    annotations = adagenes.tools.parse_vcf.extract_annotations_vcf(vcf_lines, keys)
        #else:
        if gene_request is False:
            keys = [config.uta_genomic_keys[0], config.uta_genomic_keys[1]]
        else:
            keys = list(vcf_lines.keys())
        #annotations = adagenes.tools.parse_vcf.extract_annotations_json(vcf_lines, config.uta_adapter_srv_prefix, keys)

        #gene_names = copy.deepcopy(annotations[keys[0]])
        #varexch = copy.deepcopy(annotations[keys[1]])
        #qid_list = copy.deepcopy(annotations['q_id'])

        qid_gene_name_dc = {}
        qid_list = []
        for qid in vcf_lines.keys():
            variant_data = vcf_lines[qid]
            if ("UTA_Adapter" in variant_data) and (gene_request is False):
                if ("gene_name" in variant_data["UTA_Adapter"]) and (
                        "variant_exchange" in variant_data["UTA_Adapter"]):
                    qid_gene_name_dc[variant_data["UTA_Adapter"]["gene_name"]] = qid
                    qid_list.append(variant_data["UTA_Adapter"]["gene_name"])
            elif gene_request is False:
                print("ProteinFeatures: Could not find UTA adapter section: ", variant_data)
            else:
                qid_list.append(qid)
        q_lists = list(op.tools.divide_list(copy.deepcopy(qid_list), chunk_size=100))

        for q_list in q_lists:
            q = ",".join(q_list)

            #while True:
            max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            if max_length > len(qid_list):
                max_length = len(qid_list)
            #qids_partial = qid_list[0:max_length]

            #qids_partial = adagenes.tools.filter_alternate_alleles(qids_partial)

            #genompos_str = ','.join(qids_partial)
            #gene_names_partial = \
            #    adagenes.tools.parse_vcf.extract_annotations_json_part(vcf_lines, config.uta_adapter_srv_prefix,
            #                                                         [config.uta_genomic_keys[0]],
            #                                                         qids_partial)[config.uta_genomic_keys[0]]
            #variant_exchange_partial = adagenes.tools.parse_vcf.extract_annotations_json_part(vcf_lines,
            #                                                                                config.uta_adapter_srv_prefix, [
            #                                                                                    config.uta_genomic_keys[
            #                                                                                        1]],
            #                                                                                qids_partial)[
            #    config.uta_genomic_keys[1]]

            #gene_names_str = ",".join(gene_names_partial)
            #variant_exchange_str = ",".join(variant_exchange_partial)

            qid_gene_dc = {}
            q = "?gene=" + q
            #for i in range(0, len(gene_names_partial)):
            #    q += str(gene_names_partial[i]) + ","
            #    qid_gene_dc[gene_names_partial[i]] = qids_partial[i]

            q = q.rstrip(",")
            #q += '&gene=' + genompos_str




            #vcf_lines = adagenes.processing.parse_http_responses.parse_module_response(q, vcf_lines,self.url_pattern,self.genome_version,self.srv_prefix)
            try:
                json_body = req.get_connection(q, self.url_pattern, self.genome_version)

                for key in json_body["cosmic"].keys():
                    json_obj = json_body["cosmic"][key]
                    gene = key

                    try:
                        if gene_request is False:
                            qid = qid_gene_name_dc[gene]
                        else:
                            qid = gene
                        vcf_lines[qid][self.srv_prefix] = json_obj
                    except:
                        cur_dt = datetime.datetime.now()
                        print(cur_dt, ": error processing variant response: ", qid, ';', traceback.format_exc())
            except:
                print(": error processing variant response: ;", traceback.format_exc())

            #for i in range(0, max_length):
            #    del gene_names[0]
            #    del varexch[0]
            #    del qid_list[0]
            #if len(qid_list) == 0:
            #    break

        return vcf_lines



import unittest, copy
import onkopus.onkopus_clients


class UTAAdapterProteinSequenceAnnotationTestCase(unittest.TestCase):

    def test_uta_adapter_protein_sequence_client_variant(self):
        genome_version = 'hg38'
        data = {"chr7:140753336A>T": {}, "chr10:8115913C>T":{},"chr7:140753336A>G": {}}
        variant_data = onkopus.onkopus_clients.UTAAdapterClient(
            genome_version=genome_version).process_data(data)
        variant_data = onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(
            genome_version=genome_version).process_data(variant_data)
        print("Response ",variant_data)

    def test_uta_adapter_protein_sequence_client_gene(self):
        genome_version = 'hg38'
        data = {"BRAF": {}, "NRAS": {}}
        variant_data = onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(
            genome_version=genome_version).process_data(data,gene_request=True)
        print("Response ",variant_data)
        self.assertListEqual(list(variant_data.keys()),["BRAF","NRAS"],"")




import unittest, os
import onkopus as op
import adagenes as ag


class TestCLIAnnotation(unittest.TestCase):

    def test_stream_based_annotation_revel(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        #infile = __location__ + "/../test_files/somaticMutations__cclab_brca.GRCh38.vcf"
        infile = __location__ + "/../test_files/somaticMutations.hg38.ln200.vcf"
        outfile = __location__ + "/../test_files/somaticMutations.hg38.ln200" + ".clinvar.vcf"
        #outfile = __location__ + "/../test_files/somaticMutations__cclab_brca" + ".GRCh38.vcf"

        #client = op.LiftOverClient(genome_version="hg19",target_genome="hg38")
        client = op.ClinVarClient(genome_version="hg38")
        #client = op.DBNSFPClient(genome_version="hg38")
        ag.process_file(infile, outfile, client, genome_version="hg38")






import unittest
import onkopus as op
import adagenes


class TestBiomarkerTypeConversion(unittest.TestCase):

    def test_protein_to_genomic(self):
        data = {"NRAS:Q61L": {}}
        bframe = adagenes.BiomarkerFrame(data, data_type="p")
        bframe = op.ProteinToGenomic().process_data(bframe)

        print(bframe)
        self.assertListEqual(list(bframe.data.keys()), ["chr1:114713908T>A"], "")




import argparse
import os, time, datetime
import onkopus.conf.docker_config as docker_config
import onkopus.conf.read_config as conf_reader
import adagenes as ag
import onkopus.import_data
import onkopus.mtb_requests
import onkopus as op


class OnkopusMain():

    def __init__(self):
        self.__location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        self.__data_dir__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__))) + "/data"

        self.title = "Onkopus"

        version = op.conf_reader.config["DEFAULT"]["VERSION"]
        self.version = version
        self.__available_modules__ = self._load_available_modules()
        self.module_labels = docker_config.available_modules

        # Load installed modules
        self.installed_modules = self._load_installed_modules()
        self.__docker_compose_file = self.__data_dir__ + "/docker-compose.yml"

        self.formats=["VCF","MAF","CSV","TSV","XLSX","TXT"]

    def _load_available_modules(self):
        return list(docker_config.module_ids.keys())

    def _load_installed_modules(self):
        installed_modules = []

        # Create data directory if it does not exist
        isExist = os.path.exists(self.__data_dir__)
        if not isExist:
            # Create a new directory because it does not exist
            os.makedirs(self.__data_dir__)
            print("Created data directory: ",self.__data_dir__)

        # Create modules file if it does not exist
        if not os.path.exists(self.__data_dir__ + "/" + conf_reader.config["DEFAULT"]["INSTALLED_MODULES_FILE"]):
            file = open(self.__data_dir__ + "/" + conf_reader.config["DEFAULT"]["INSTALLED_MODULES_FILE"], 'w+')
            file.close()
        if not os.path.exists(self.__data_dir__ +
                              "/docker-compose.yml"):
            os.system("cp -v " + self.__location__ + "/conf/docker_compose/docker-compose.yml " + self.__data_dir__ + "/docker-compose.yml")

        file = open(self.__data_dir__ + "/" + conf_reader.config["DEFAULT"]["INSTALLED_MODULES_FILE"], 'r')
        for line in file:
            installed_modules.append(line.strip())
        file.close()

        print("Installed modules: ", installed_modules)

        return installed_modules

    def _add_new_module(self, module):
        with open(self.__data_dir__ + "/" + conf_reader.config["DEFAULT"]["INSTALLED_MODULES_FILE"], "a") as file:
            file.write(module+'\n')

        self.installed_modules.append(module)

    def _db_request(self, pid, module=None, genome_version=None):
        """

        :param pid:
        :param module:
        :param genome_version:
        :return:
        """
        print("Annotate biomarkers of ID: ",pid,", genome version: ", genome_version, ", module: ",module)

        onkopus_server_url = conf_reader.__MODULE_PROTOCOL__ + "://" + conf_reader.__MODULE_SERVER__ + conf_reader.__PORT_ONKOPUS_SERVER__
        onkopus_server_url = onkopus_server_url + "/onkopus-server/v1/analyze_variants"

        onkopus.import_data.annotate_variant_data(pid, onkopus_server_url=onkopus_server_url,
                                        genome_version=genome_version,module=module)

    def _module_request(self, input_file, output_file, module, genome_version=None,
                        input_format=None,output_format=None, target=None, data_type="g"):
        """
        Annotates a variant file with the defined module and writes the annotated variant file in the file system.
        Directly employs the Onkopus clients, without writing the results in the Onkopus database

        :param input_file:
        :param output_file:
        :param module:
        :param genome_version:
        :return:
        """
        # Get Onkopus client
        #print("Query ", module)
        modules = module.split(",")

        #print("Run Onkopus annotation")
        print("Input file ", input_file)
        #print("Output file ", output_file)

        # Read in input file
        #bframe = onkopus.read_file(input_file, input_format=input_format)

        # Employ CCS GeneToGenomic service if data is in protein format
        #if bframe.data_type == "p":
        #    print("Proteomic data detected: Retrieving genomic locations")
        #    genome_version = "hg38"
        #    client = CCSGeneToGenomicClient(genome_version)
        #    bframe.data = client.process_data(bframe.data, input_format='tsv')

        if (genome_version == "hg19") or (genome_version == "t2t"):
            if module != "liftover":
                print("Converting variant data to GRCh38...",genome_version)
                output_file_liftover = input_file + ".GRCh38.avf "
                obj = op.LiftOverClient(genome_version=genome_version,target_genome="hg38")
                ag.process_file(input_file, output_file_liftover, obj, genome_version=genome_version, input_format=input_format,
                                output_format=output_format, error_logfile=None)
                input_file = output_file_liftover
                genome_version = "hg38"
                print("Liftover successful.")

        # Annotate
        for m in modules:
            obj = onkopus.get_onkopus_client(m, genome_version, target=target, data_type=data_type)
            #print("client ", type(client))
            if obj is None:
                print("Error: Onkopus module not found: ", m)
                exit(1)

            ag.process_file(input_file, output_file, obj, genome_version=genome_version, input_format=input_format,
                                       output_format=output_format, error_logfile=None)



    def run_interpretation(self,
                           input_file,
                           output_file,
                           module=None,
                           genome_version=None,
                           pid=None,
                           input_format=None,
                           output_format=None,
                           mode=None,
                           target=None
                           ):
        """
        Annotates an input file with the defined module. The annotated file is saved in the given output path

        :param input_file:
        :param output_file:
        :param module:
        :param genome_version:
        :return:
        """
        if mode == "test":
            __location__ = os.path.realpath(
                os.path.join(os.getcwd(), os.path.dirname(__file__)))
            #file = __location__ + '/tests/test_files'
            input_file = __location__ + '/../tests/test_files' + '/' + input_file

        #print("Starting interpretation")
        time_start = time.time()

        # Check input file parameter
        if input_file == '':
            if pid is None:
                print("Error: No input file passed. Please define an input file with the -i option, e.g. onkopus run -i /path/to/file/mutations.vcf.gz")
                exit(1)
            else:
                print("Annotate patient biomarkers: ",pid)
                self._db_request(pid, module=module, genome_version=genome_version)
                exit(0)

        file_name, file_extension = os.path.splitext(input_file)
        input_format_recognized = file_extension.lstrip(".")
        if input_format_recognized == "gz":
            #print("Found .gz file")
            file_name, file_extension = os.path.splitext(file_name)
            input_format_recognized = file_extension.lstrip(".")

        if input_format == "":
            input_format = input_format_recognized
            print("Recognized input format: ",input_format)

        # get output format
        if output_format == "":
            output_format = input_format_recognized
            print("No output format given. Using input file format: ",input_format)

        if output_file == '':
            datetime_str = str(datetime.datetime.now())
            basefile = os.path.splitext(input_file)[0]
            output_file = basefile + '.' + datetime_str + ".ann." + output_format
            print("No output file defined. Generated output file path: ", output_file)

        if conf_reader.config["DEFAULT"]["MODE"] == "LOC":
            print("local mode")

            # Check if Onkopus modules are running

        elif conf_reader.config["DEFAULT"]["MODE"] == "PUB":
            #print("public mode")

            module_server = conf_reader.__MODULE_PROTOCOL__ + '//' + conf_reader.__MODULE_SERVER__
            print("Module server: ", module_server)


        # Get active modules
        active_modules = []
        try:
            active_modules = conf_reader.config["DEFAULT"]["ACTIVE_MODULES"].split(",")
            print("Active modules: ",active_modules)

        except:
            print("Error: Could not read active modules")
            exit(1)

        # Query all modules if module is set to 'all'
        #if module == 'all':
        #    for module in active_modules:
        #        self.module_request(input_file, output_file, module, genome_version=genome_version)
        #else:
        self._module_request(input_file, output_file, module, genome_version=genome_version,
                             input_format=input_format,output_format=output_format, target=target)

        print("File annotated: ",module,", annotations written in: ",output_file)

        time_stop = time.time()
        time_total = (time_stop - time_start)
        print("Annotation time: ",str(time_total))

    def import_data(self,input_file, genome_version=None,data_dir=None):
        """
        Imports an input file or all files within a directory as patient biomarker data in the Onkopus database

        :param input_file:
        :param genome_version:
        :param data_dir:
        :return:
        """
        if (data_dir is not None) and (data_dir != ''):
            # import all files in directory
            pass
        elif input_file != '':
            # import file
            print("Import file: ",input_file)

            onkopus_server_url = conf_reader.__MODULE_PROTOCOL__ + "://" + conf_reader.__MODULE_SERVER__ + conf_reader.__PORT_ONKOPUS_SERVER__
            onkopus_server_url = onkopus_server_url + "/onkopus-server/v1/upload_variant_data"

            pid = onkopus.import_data.import_file(input_file, onkopus_server_url=onkopus_server_url, genome_version=genome_version)
            return pid
        else:
            print("Error: No input file defined. Define an input file or a data directory")

    def install(self, module):
        """
        Installs an Onkopus module

        :param module:
        :return:
        """
        print("Install Onkopus module: ",module)

        # Check if module is already installed
        if module in self.installed_modules:
            print("Module " + module + " is already installed")
            return

        # Download databases
        print(self.__available_modules__)
        if module in self.__available_modules__:
            # get installation directory
            self.__location__ = os.path.realpath(
                os.path.join(os.getcwd(), os.path.dirname(__file__)))

            # Run preprocessing shell script
            print("Running preprocessing script for ",module, end='')
            preprocessing_script = self.__location__ + "/preprocess/preprocess_"+module+".sh"
            if os.path.exists(preprocessing_script):
                print("Running preprocessing script...")
                os.system(preprocessing_script + self.__data_dir__)

            # add Docker compose entry
            print("Adding Docker compose entry for " + module + "...", end='')
            template_files = [self.__location__ + "/conf/docker_compose/" + module + ".yml"]
            if module == "uta-adapter":
                template_files.append(self.__location__ + "/conf/docker_compose/uta-database.yml")

            for tfile in template_files:
                template_file = open(tfile)
                lines = []
                for line in template_file:
                    lines.append(line)

                with open(self.__docker_compose_file, "a") as dc_file:
                    for line in lines:
                        dc_file.write(line)
                template_file.close()

            # pull Onkopus module Docker container
            print("Pull Docker container for " + module, end='')
            os.system("docker-compose -f " + self.__data_dir__ + "/docker-compose.yml pull")

            self._add_new_module(module)

            print("Onkopus module successfully installed: " + module)
        else:
            print("[Error] No Onkopus module found: " + module + ". Get a list of all available modules with 'onkopus list-modules'")

    def start_modules(self):
        """
        Starts all installed Onkopus modules as Docker containers

        :return:
        """
        print("Starting locally installed Onkopus modules")

        print("Installed modules: " + ",".join(self.installed_modules))

        # Start Docker containers
        dc_cmd = "docker-compose -f " + self.__data_dir__ + "/docker-compose.yml up -d"
        #print(dc_cmd)
        os.system(dc_cmd)

        print("Onkopus started")

    def stop_modules(self):
        """
        Stops all running Onkopus containers

        :return:
        """
        print("Stopping Onkopus modules")

        os.system("docker-compose -f " + self.__data_dir__ + "/docker-compose.yml down")

        print("Onkopus stopped")

    def restart_modules(self):
        """
        Restarts all installed Onkopus modules

        :return:
        """
        os.system('docker-compose down')
        os.system('docker-compose pull')
        os.system('docker-compose up -d')

    def list_modules(self):
        """
        Prints a list of all available Onkopus modules

        :return:
        """
        print("Available Onkopus modules: ")
        #print(self.__available_modules__)
        print(self.module_labels)

        print("Install an Onkopus module locally by running 'onkopus install -m [module-name]'")

    def list_formats(self):
        """

        :return:
        """
        print("Available data formats for input format (-if) and output format (-of): ")
        for format in self.formats:
            print(format)

    def add_patient_to_mtb(self,pid,mtb):
        onkopus_server_url = conf_reader.__MODULE_PROTOCOL__ + "://" + conf_reader.__MODULE_SERVER__ + conf_reader.__PORT_ONKOPUS_SERVER__
        onkopus_server_url = onkopus_server_url + "/onkopus-server/v1/updateMTB"
        onkopus.mtb_requests.add_patient_to_mtb(pid,mtb, onkopus_server_url)

    def add_patient_and_perform_annotation(self, input_file, mtb, genome_version=None, data_dir=None):
        pid = self.import_data(input_file, genome_version=genome_version, data_dir=data_dir)
        module = 'all'
        data_dir = "loc"
        self._db_request(pid, module=module, genome_version=genome_version)
        self.add_patient_to_mtb(pid, mtb)

    def show_title(self):
        pass

    def run(self):
        """
        Main Onkopus command-line function

        :return:
        """
        self.show_title()

        parser = argparse.ArgumentParser()
        parser.add_argument('action', choices=['run', 'install', 'list-modules', 'start', 'stop', 'import', 'mtb-add', 'mtb-add-analyze'])
        parser.add_argument('-m', '--module', default='all')
        parser.add_argument('-i', '--input_file', default='')
        parser.add_argument('-o', '--output_file', default='')
        parser.add_argument('-g', '--genome_version', default='')
        parser.add_argument('-d', '--data_dir', default='')
        parser.add_argument('-pid', '--patient_id', default='')
        parser.add_argument('-mtb', '--mtb_id', default='')
        parser.add_argument('-if', '--input_format', default='')
        parser.add_argument('-of', '--output_format', default='')
        parser.add_argument('-md', '--mode', default='')
        parser.add_argument('-t', '--target', default='hg38')

        args = parser.parse_args()
        action = args.action
        module = args.module
        input_file = args.input_file
        output_file = args.output_file
        genome_version = args.genome_version
        data_dir = args.data_dir
        pid = args.patient_id
        mtb = args.mtb_id
        input_format = args.input_format
        output_format = args.output_format
        mode = args.mode
        target = args.target

        if action == 'run':
            self.run_interpretation(input_file, output_file, module=module, genome_version=genome_version, pid=pid,
                                    input_format=input_format,output_format=output_format,mode=mode, target=target)
        elif action == 'install':
            self.install(module)
        elif action == 'start':
            self.start_modules()
        elif action == 'stop':
            self.stop_modules()
        elif action == 'import':
            self.import_data(input_file, genome_version=genome_version,data_dir=data_dir)
        elif action == 'list-modules':
            self.list_modules()
        elif action == 'list-formats':
            self.list_formats()
        elif action == 'mtb-add':
            self.add_patient_to_mtb(pid,mtb)
        elif action == 'mtb-add-analyze':
            self.add_patient_and_perform_annotation(input_file, mtb, genome_version=genome_version, data_dir=data_dir)




import unittest, os
import onkopus.onkopus_clients
import onkopus as op
import adagenes

class DBNSFPAnnotationTestCase(unittest.TestCase):

    def test_dbnsfp_client(self):
        genome_version = 'hg38'
        data = {"chr10:8073950C>T": {}}

        data = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version).process_data(data)
        data = adagenes.LiftoverAnnotationClient(genome_version=genome_version).process_data(data)
        variant_data = onkopus.onkopus_clients.DBNSFPClient(
            genome_version=genome_version).process_data(data)

        self.assertEqual(str(variant_data["chr10:8073950C>T"]["dbnsfp"]["ALFA_European_AN"]), "9690",
                         "Value does not match")
        self.assertEqual(str(variant_data["chr10:8073950C>T"]["dbnsfp"]["FATHMM_score"]), "-4.08;.;-4.05",
                         "Value does not match")
        self.assertEqual(str(variant_data["chr10:8073950C>T"]["dbnsfp"]["MVP_score"]), "0.825523400301;.;0.825523400301",
                         "Value does not match")
        self.assertEqual(str(variant_data["chr10:8073950C>T"]["dbnsfp"]["AlphaMissense_pred"]), "B;.;B",
                         "Value does not match")
        self.assertEqual(str(variant_data["chr10:8073950C>T"]["dbnsfp"]["ESM1b_score"]), "-11.023;-11.023;-10.794",
                         "Value does not match")
        self.assertEqual(variant_data["chr10:8073950C>T"]["dbnsfp"]["AlphaMissense_score_aggregated_value"],"0.137","Value does not match")

    def test_dbnsfp_client_batch(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        genome_version = 'hg19'
        file= __location__ + '/../../test_files/somaticMutations_brca_ln250.avf'

        data = onkopus.read_file(file, genome_version=genome_version)
        data = adagenes.LiftoverClient(genome_version=genome_version).process_data(data, target_genome="hg38")
        data.data = onkopus.onkopus_clients.UTAAdapterClient(genome_version=data.genome_version).process_data(data.data)
        data.data = onkopus.onkopus_clients.DBNSFPClient(
            genome_version=data.genome_version).process_data(data.data)

        print("AM score ",data.data["chr10:8073950C>T"]["dbnsfp"]["AlphaMissense_score_aggregated_value"])

        #print(data.data["chr10:8073950C>T"]["dbnsfp"])
        self.assertEqual(str(data.data["chr10:8073950C>T"]["dbnsfp"]["ALFA_European_AN"]), "9690","Value does not match")
        self.assertEqual(str(data.data["chr10:8073950C>T"]["dbnsfp"]["FATHMM_score"]), "-4.08;.;-4.05",
                         "Value does not match")
        self.assertEqual(str(data.data["chr10:8073950C>T"]["dbnsfp"]["MVP_score"]), "0.825523400301;.;0.825523400301",
                         "Value does not match")
        self.assertEqual(str(data.data["chr10:8073950C>T"]["dbnsfp"]["AlphaMissense_pred"]), "B;.;B",
                         "Value does not match")
        self.assertEqual(str(data.data["chr10:8073950C>T"]["dbnsfp"]["ESM1b_score"]), "-11.023;-11.023;-10.794",
                         "Value does not match")



import unittest
import onkopus.onkopus_clients


class AlphaMissenseAnnotationTestCase(unittest.TestCase):

    def test_alphamissense_client(self):
        genome_version = 'hg38'

        data = {"chr7:140753336A>T": {}, "chr7:140753336A>G": {}}

        variant_data = onkopus.onkopus_clients.AlphaMissenseClient(
            genome_version=genome_version).process_data(data)

        print("Response ",variant_data)





import traceback
import adagenes.tools.module_requests as req
from onkopus.conf import read_config as config


class CCSGeneFusionClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version

    def process_data(self,
                     annotated_data):
        """
        Looks up genomic data of variant calls from gene names and variant exchange data

        Parameters
        ----------
        vcf
        variant_str

        Returns
        -------
        :param annotated_data:

        """

        # generate query string
        variant_str = ",".join(annotated_data.keys())
        if variant_str == "":
            return annotated_data

        try:
            json_body = req.get_connection(variant_str,
                  config.uta_adapter_genefusion_src,
                  self.genome_version)

            for result in json_body:
                if result["data"] is not None:
                    qid = result['header']['qid']
                    annotated_data[qid][config.uta_adapter_genefusion_srv_prefix] = result['data']

                    annotated_data[qid][config.variant_data_key] = {}
                    annotated_data[qid][config.variant_data_key]["type"] = "fusion"
        except:
            print("error: genomic to gene")
            print(traceback.format_exc())

        return annotated_data




def get_gene_names(vcf_lines):
    gene_names = []
    for var in vcf_lines.keys():
        if "UTA_Adapter" in var.keys():
            if "gene_name" in var["UTA_Adapter"]:
                gene_names.append(var["UTA_Adapter"]["gene_name"])
            else:
                gene_names.append("")
        elif "UTA_Adapter_gene_name" in var.keys():
            gene_names.append(var["UTA_Adapter_gene_name"])
        else:
            gene_names.append("")
    return gene_names



import unittest

import adagenes.tools.json_mgt


class TestPreprocessing(unittest.TestCase):

    def test_default_key_generation(self):
        variant_data = {"chr1:114713908T>A": {}}

        #variant_data = adagenes.tools.json_mgt.generate_keys(variant_data)
        #print(variant_data)



import unittest
import onkopus as op
import adagenes as ag


class TestGeneAnnotation(unittest.TestCase):

    def test_gene_annotation(self):
        data = {"TP53":{ "mutation_type": "gene" }}
        bframe = ag.BiomarkerFrame(data)
        data = op.annotate_genes(bframe.data)
        #print(data.keys())

        self.assertEqual(list(data["TP53"].keys()), ["civic", "cosmic","gencode",  "mdesc", "mutation_type"
            , "onkopus_aggregator"
            ,
                                                     "type",
                                                     "UTA_Adapter"],"")




import copy, gzip, os, traceback, time
from multiprocessing import Process, Pool
import copy
import adagenes
import adagenes

import onkopus.onkopus_clients
import multiprocessing
from onkopus.processing.threads import ThreadWithReturnValue


def parallel_interpreter_requests(annotated_data,genome_version):
    """
    Parallelized requests to the data interpretation modules (Treatment aggregator and pathogenicity interpreter)

    :param variant_data:
    :param genome_version:
    :return:
    """
    start_time = time.time()

    task1 = onkopus.onkopus_clients.AggregatorClient(genome_version=genome_version).process_data
    #task2 = onkopus.onkopus_clients.InterpreterClient(genome_version=genome_version).process_data

    t1 = ThreadWithReturnValue(target=task1, args=[annotated_data])
    #t2 = ThreadWithReturnValue(target=task2, args=[annotated_data])

    t1.start()
    #t2.start()

    data1 = t1.join()
    #data2 = t2.join()

    annotated_data = adagenes.merge_dictionaries(annotated_data, data1)
    #annotated_data = adagenes.merge_dictionaries(annotated_data, data2)

    stop_time = time.time() - start_time
    print("Time for parallel interpretation requests: ", stop_time)

    return annotated_data


def multiprocess_requests(annotated_data, genome_version):
    """
    Run parallel annotation requests on multiple CPUs

    :param annotated_data:
    :param genome_version:
    :return:
    """

    start_time = time.time()

    tasks = [
        onkopus.onkopus_clients.DBSNPClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.ClinVarClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.REVELClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.LoFToolClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.VUSPredictClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.MetaKBClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.MVPClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.PrimateAIClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.DBNSFPClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.ProteinFeatureClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.GENCODEGenomicClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.CIViCClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.OncoKBClient(genome_version=genome_version).process_data,
        onkopus.onkopus_clients.AlphaMissenseClient(genome_version=genome_version).process_data
    ]

    data = [
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data),
        copy.deepcopy(annotated_data)
    ]

    p = Pool(processes=len(tasks))#
    for i in range(0, len(tasks)):
        task = tasks[i]
        data[i] = p.apply_async(task, args=(data[i],)) #p.map(tasks[i], annotated_data)
    p.close()
    p.join()

    annotated_data={}
    for module_data in data:
        #print("merge ",module_data.get())
        annotated_data = adagenes.merge_dictionaries(annotated_data,module_data.get())
    #print(annotated_data)

    stop_time = time.time() - start_time
    print("Time for parallel annotation requests: ", stop_time)

    return annotated_data


def parallel_requests(annotated_data, genome_version,oncokb_key=None):
    """
    Annotates a biomarker frame with parallelized Onkopus requests

    :param annotated_data:
    :param genome_version:
    :param oncokb_key: Private OncoKB account access token (Required for including OncoKB results)
    :return:
    """
    start_time = time.time()

    task1 = onkopus.onkopus_clients.DBSNPClient(genome_version=genome_version).process_data
    task2 = onkopus.onkopus_clients.ClinVarClient(genome_version=genome_version).process_data
    task3 = onkopus.onkopus_clients.REVELClient(genome_version=genome_version).process_data
    task4 = onkopus.onkopus_clients.LoFToolClient(genome_version=genome_version).process_data
    task5 = onkopus.onkopus_clients.MolecularFeaturesClient(genome_version=genome_version).process_data
    task6 = onkopus.onkopus_clients.MetaKBClient(genome_version=genome_version).process_data
    task7 = onkopus.onkopus_clients.MVPClient(genome_version=genome_version).process_data
    task8 = onkopus.onkopus_clients.PrimateAIClient(genome_version=genome_version).process_data
    task9 = onkopus.onkopus_clients.DBNSFPClient(genome_version=genome_version).process_data
    task10 = onkopus.onkopus_clients.ProteinFeatureClient(genome_version=genome_version).process_data
    task11 = onkopus.onkopus_clients.GENCODEGenomicClient(genome_version=genome_version).process_data
    task12 = onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(genome_version=genome_version).process_data
    task13 = onkopus.onkopus_clients.CIViCClient(genome_version=genome_version).process_data
    task14 = onkopus.onkopus_clients.OncoKBClient(genome_version=genome_version).process_data
    task15 = onkopus.onkopus_clients.AlphaMissenseClient(genome_version=genome_version).process_data
    task16 = adagenes.BLOSUMClient().process_data
    task17 = onkopus.onkopus_clients.COSMICGeneCensusClient(genome_version=genome_version).process_data
    task18 = adagenes.LiftoverAnnotationClient(genome_version=genome_version).process_data
    task19 = onkopus.onkopus_clients.GeneExpressionClient().process_data

    annotated_data_oncokb = copy.deepcopy(annotated_data)
    annotated_data_oncokb["oncokbkey"] = oncokb_key

    t1 = ThreadWithReturnValue(target=task1, args=[annotated_data])
    t2 = ThreadWithReturnValue(target=task2, args=[annotated_data])
    t3 = ThreadWithReturnValue(target=task3, args=[annotated_data])
    t4 = ThreadWithReturnValue(target=task4, args=[annotated_data])
    t5 = ThreadWithReturnValue(target=task5, args=[annotated_data])
    t6 = ThreadWithReturnValue(target=task6, args=[annotated_data])
    t7 = ThreadWithReturnValue(target=task7, args=[annotated_data])
    t8 = ThreadWithReturnValue(target=task8, args=[annotated_data])
    t9 = ThreadWithReturnValue(target=task9, args=[annotated_data])
    t10 = ThreadWithReturnValue(target=task10, args=[annotated_data])
    t11 = ThreadWithReturnValue(target=task11, args=[annotated_data])
    t12 = ThreadWithReturnValue(target=task12, args=[annotated_data])
    t13 = ThreadWithReturnValue(target=task13, args=[annotated_data])
    t14 = ThreadWithReturnValue(target=task14, args=[annotated_data_oncokb])
    t15 = ThreadWithReturnValue(target=task15, args=[annotated_data])
    t16 = ThreadWithReturnValue(target=task16, args=[annotated_data])
    t17 = ThreadWithReturnValue(target=task17, args=[annotated_data])
    t18 = ThreadWithReturnValue(target=task18, args=[annotated_data])
    t19 = ThreadWithReturnValue(target=task19, args=[annotated_data])

    t1.start()
    t2.start()
    t3.start()
    t4.start()
    t5.start()
    t6.start()
    t7.start()
    t8.start()
    t9.start()
    t10.start()
    t11.start()
    t12.start()
    t13.start()
    t14.start()
    t15.start()
    t16.start()
    t17.start()
    t18.start()
    t19.start()

    data1 = t1.join()
    data2 = t2.join()
    data3 = t3.join()
    data4 = t4.join()
    data5 = t5.join()
    data6 = t6.join()
    data7 = t7.join()
    data8 = t8.join()
    data9 = t9.join()
    data10 = t10.join()
    data11 = t11.join()
    data12 = t12.join()
    data13 = t13.join()
    data14 = t14.join()
    data15 = t15.join()
    data16 = t16.join()
    data17 = t17.join()
    data18 = t18.join()
    data19 = t19.join()

    annotated_data = adagenes.merge_dictionaries(annotated_data, data1)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data2)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data3)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data4)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data5)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data6)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data7)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data8)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data9)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data10)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data11)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data12)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data13)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data14)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data15)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data16)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data17)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data18)
    annotated_data = adagenes.merge_dictionaries(annotated_data, data19)

    stop_time = time.time() - start_time
    print("Time for parallel annotation requests: ",stop_time)

    return annotated_data





from adagenes.tools import get_biomarker_type_aaexchange


class BiomarkerRecognitionClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version

    def process_data(self,annotated_data):

        annotated_data = get_biomarker_type_aaexchange(annotated_data)

        return annotated_data



import traceback, copy
import adagenes.tools.module_requests as req
from onkopus.conf import read_config as config
import adagenes.tools.parse_genomic_data
import onkopus as op


class UTAAdapterProteinSequenceClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines = config.uta_adapter_protein_sequence_info_lines
        self.url_pattern = config.uta_adapter_protein_sequence_src
        self.srv_prefix = config.uta_adapter_protein_sequence_srv_prefix
        self.genomic_keys = config.uta_genomic_keys
        self.gene_keys = config.uta_gene_keys
        self.gene_response_keys = config.uta_gene_response_keys
        self.extract_keys = config.uta_genomic_keys

        self.qid_key = "q_id"
        if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
            self.qid_key = "q_id_hg19"

    def process_data(self, data, gene_request=False):
        #keys = [config.uta_genomic_keys[0],
        #            config.uta_genomic_keys[1]]
        #annotations = adagenes.tools.parse_vcf.extract_annotations_json(vcf_lines, config.uta_adapter_srv_prefix, keys)
        #gene_names = copy.deepcopy(annotations[keys[0]])
        #variant_exchange = copy.deepcopy(annotations[keys[1]])
        #qid_list = copy.deepcopy(annotations['q_id'])

        qid_gene_name_dc = {}
        qid_list = []
        for qid in data.keys():
            variant_data = data[qid]
            if ("UTA_Adapter" in variant_data) and (gene_request is False):
                if ("gene_name" in variant_data["UTA_Adapter"]) and ("variant_exchange" in variant_data["UTA_Adapter"]):
                    qid_gene_name_dc[variant_data["UTA_Adapter"]["gene_name"] + ':' + variant_data["UTA_Adapter"][
                        "variant_exchange"]] = [qid]
                    qid_list.append(variant_data["UTA_Adapter"]["gene_name"] + ':' + variant_data["UTA_Adapter"][
                        "variant_exchange"])
            elif ("gene_name" in variant_data) and ("variant_exchange" in variant_data):
                qid_gene_name_dc[variant_data["gene_name"] + ':' + variant_data["variant_exchange"]] = [qid]
                qid_list.append(variant_data["gene_name"] + ':' + variant_data["variant_exchange"])
            elif "gene_name" in variant_data:
                qid_gene_name_dc[variant_data["gene_name"]] = [qid]
                qid_list.append(variant_data["gene_name"])
            elif "gene" in variant_data:
                if variant_data["gene"] in qid_gene_name_dc.keys():
                    qid_gene_name_dc[variant_data["gene"]].append(qid)
                else:
                    qid_gene_name_dc[variant_data["gene"]] = [qid]
                qid_list.append(variant_data["gene"])
            elif gene_request is False:
                print("ProteinFeatures: Could not find UTA adapter section: ", variant_data)
            else:
                qid_list.append(qid)
        q_lists = list(op.tools.divide_list(copy.deepcopy(qid_list), chunk_size=100))

        for q_list in q_lists:
            q = ",".join(q_list)

            #while True:

            max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            if max_length > len(qid_list):
                max_length = len(qid_list)
            #qids_partial = qid_list[0:max_length]
            #qids_partial = adagenes.tools.filter_alternate_alleles(qids_partial)

            #gene_names_partial = gene_names[0:max_length]
            #variant_exchange_partial = variant_exchange[0:max_length]

            max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            if max_length > len(qid_list):
                max_length = len(qid_list)
            qids_partial = qid_list[0:max_length]

            #if gene_request:
            #    q = ','.join(qids_partial)
            #else:
            #    variants = []
            #    for gene,variant in zip(gene_names_partial,variant_exchange_partial):
            #        if (gene != '') and (variant != ''):
            #            variants.append(gene + ":" + variant)
            #    q = ','.join(variants)
            a = ','.join(q_list)

            try:
                json_body = req.get_connection(q, self.url_pattern, self.genome_version)

                for key in json_body[0].keys():
                        if gene_request is False:
                            if str(json_body[0][key]["header"]["qid"]) in qid_gene_name_dc.keys():
                                qids = qid_gene_name_dc[str(json_body[0][key]["header"]["qid"])]

                        else:
                            #qid_index = q_list.index(str(json_body[0][key]["header"]["qid"]))
                            #qid = qids_partial[qid_index]
                            qid = str(json_body[0][key]["header"]["qid"])
                            #print("genompos for ",str(json_body[0][key]["header"]["qid"]),": ",qid)

                        if json_body[0][key]["data"] is not None:
                            if type(json_body[0][key]["data"]) is dict:
                                #print("available qids: ",list(vcf_lines.keys()))
                                for qid in qids:
                                    data[qid][self.srv_prefix] = json_body[0][key]["data"]
                            else:
                                for qid in qids:
                                    data[qid][self.srv_prefix] = {}
                                    data[qid][self.srv_prefix]["status"] = 400
                                    data[qid][self.srv_prefix]["msg"] = json_body[0][key]["data"]
            except:
                print("error: genomic to gene")
                print(traceback.format_exc())

            #for i in range(0, max_length):
            #    del qid_list[0]  # qid_list.remove(qid)
            #if len(qid_list) == 0:
            #    break

        return data



import unittest, copy, os
import onkopus as op
import adagenes as ag

class UTAAdapterAnnotationTestCase(unittest.TestCase):

    def test_uta_adapter_client(self):
        genome_version = 'hg38'

        data = {"chr7:140753336A>T": {}}

        variant_data = op.UTAAdapterClient(
            genome_version=genome_version).process_data(data)

        self.assertEqual(variant_data["chr7:140753336A>T"]["UTA_Adapter"]["gene_name"],"BRAF")
        self.assertEqual(variant_data["chr7:140753336A>T"]["UTA_Adapter"]["variant"],"NP_004324.2:p.(Val600Glu)")

    def test_uta_adapter_deletion(self):
        genome_version = 'hg38'

        data = {"chr15:25356042CTCTG>C": {"variant_data":{"CHROM":"15","POS":25356042,"REF":"CTCTG","ALT":"C"}}}
        bframe = ag.BiomarkerFrame(data)
        #print(bframe.data)

        variant_data = op.UTAAdapterClient(
            genome_version=genome_version).process_data(bframe.data)

        #self.assertEqual(variant_data["chr7:140753336A>T"]["UTA_Adapter"]["gene_name"],"BRAF")
        #self.assertEqual(variant_data["chr7:140753336A>T"]["UTA_Adapter"]["variant"],"NP_004324.2:p.(Val600Glu)")

    def test_uta_adapter_client_batch(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        genome_version = 'hg19'

        infile = __location__ + "/../../test_files/somaticMutations.vcf"

        bframe = op.read_file(infile,genome_version=genome_version)
        bframe = ag.LiftoverClient(bframe.genome_version).process_data(bframe,target_genome="hg38")
        bframe.data = op.onkopus_clients.UTAAdapterClient(
            genome_version=bframe.genome_version).process_data(bframe.data)

        print("Response ",bframe.data)



from .aggregated_clients import *
from .single_module_clients import *
from .ccs_genomic_client import *
from .dbsnp_client import *
from .clinvar_client import *
from .revel_client import *
from .loftool_client import *
from .vuspredict_client import *
from .uta_adapter_client import *
from .metakb_client import *
from .ccs_liftover_client import *
from .ccs_gene_fusion_client import *
from .mvp_client import *
from .civic_client import *
from .oncokb_client import *
from .aggregator_client import *
from .primateai_client import *
from .dbnsfp_client import *
from .biomarker_recognition_client import *
from .drugclass_client import *
from .processing import *



import unittest, copy
import onkopus.onkopus_clients


class GencodeGeneNameTestCase(unittest.TestCase):

    def test_gencode_client(self):
        genome_version = 'hg19'

        data = {"TP53": {}, "KRAS": {}}

        #variant_data = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version).process_data(data)
        variant_data = onkopus.onkopus_clients.GENCODEGeneNameClient(
            genome_version=genome_version).process_data(data)

        print("Response ",variant_data)




import traceback, datetime, json
import adagenes.tools.module_requests as req
from onkopus.conf import read_config as config


class InterpreterClient:

    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.info_lines= config.onkopus_interpreter_info_lines
        self.url_pattern = config.onkopus_interpreter_src
        self.srv_prefix = config.onkopus_interpreter_srv_prefix
        self.response_keys = config.onkopus_interpreter_response_keys
        self.extract_keys = config.onkopus_interpreter_keys

        self.qid_key = "q_id"
        if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
            self.qid_key = "q_id_hg19"
        self.error_logfile = error_logfile

    def process_data(self, biomarker_data, tumor_type=None):
        """

        :param biomarker_data:
        :param tumor_type:
        :return:
        """
        try:
            biomarker_data = req.post_connection(biomarker_data,self.url_pattern,self.genome_version, tumor_type=tumor_type)
            biomarker_data_json = json.loads(biomarker_data)
            return biomarker_data_json

        except:
            if self.error_logfile is not None:
                cur_dt = datetime.datetime.now()
                date_time = cur_dt.strftime("%m/%d/%Y, %H:%M:%S")
                print("error processing request: ", biomarker_data, file=self.error_logfile+str(date_time)+'.log')
            else:
                print(": error processing variant response: ;", traceback.format_exc())

        return biomarker_data



import unittest, copy
import onkopus.onkopus_clients

class GencodeMANESelectTestCase(unittest.TestCase):

    def test_gencode_client(self):
        genome_version = 'hg38'
        data = {"chr7:140753336A>T": {}, "chr10:8115913C>T": {}}

        variant_data = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version).process_data(data)
        variant_data = onkopus.onkopus_clients.LiftOverClient(genome_version=genome_version).process_data(variant_data)
        variant_data = onkopus.onkopus_clients.GENCODEMANESelectClient(
            genome_version=genome_version).process_data(variant_data)

        print("Response ",variant_data)





import json
import traceback
from typing import Dict
from onkopus.conf import read_config as conf_reader
from onkopus.onkopus_clients import CCSGeneToGenomicClient
import onkopus.onkopus_clients
import adagenes
from onkopus.processing.parallel_requests import parallel_requests,parallel_interpreter_requests


def get_onkopus_client(module, genome_version, target=None, data_type=None):
    """
    Returns an Onkopus module client by identifier

    :param module:
    :param genome_version:
    :return:
    """
    if (module == 'ccs') or (module == 'genomic_to_gene'):
        return onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version)
    if module == 'ccs_liftover':
        return onkopus.onkopus_clients.LiftOverClient(genome_version=genome_version)
    if module == 'ccs_gene':
        client = onkopus.onkopus_clients.CCSGeneToGenomicClient(genome_version=genome_version, data_type=data_type)
        return client
    if module == 'dbsnp':
        return onkopus.onkopus_clients.DBSNPClient(genome_version=genome_version)
    if module == 'clinvar':
        return onkopus.onkopus_clients.ClinVarClient(genome_version=genome_version)
    if module == 'revel':
        return onkopus.onkopus_clients.REVELClient(genome_version=genome_version)
    if module == 'loftool':
        return onkopus.onkopus_clients.LoFToolClient(genome_version=genome_version)
    if module == 'vuspredict':
        return onkopus.onkopus_clients.VUSPredictClient(genome_version=genome_version)
    if module == 'metakb':
        return onkopus.onkopus_clients.MetaKBClient(genome_version=genome_version)
    if module == 'mvp':
        return onkopus.onkopus_clients.MVPClient(genome_version=genome_version)
    if module == 'primateai':
        return onkopus.onkopus_clients.PrimateAIClient(genome_version=genome_version)
    if module == 'alphamissense':
        return onkopus.onkopus_clients.AlphaMissenseClient(genome_version=genome_version)
    if module == 'dbnsfp':
        return onkopus.onkopus_clients.DBNSFPClient(genome_version=genome_version)
    if module == 'gencode':
        return onkopus.onkopus_clients.GENCODEGenomicClient(
            genome_version=genome_version)
    if module == 'gencode_genomic':
        return onkopus.onkopus_clients.GENCODEGenomicClient(
            genome_version=genome_version)
    if module == 'uta_adapter_protein_sequence':
        return onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(genome_version=genome_version)
    if module == 'civic':
        return onkopus.onkopus_clients.CIViCClient(genome_version=genome_version)
    if module == 'oncokb':
        return onkopus.onkopus_clients.OncoKBClient(genome_version=genome_version)
    if module == 'aggregator':
        return onkopus.onkopus_clients.AggregatorClient(genome_version=genome_version)
    if module == 'biomarker_types':
        return onkopus.onkopus_clients.BiomarkerRecognitionClient(genome_version=genome_version)
    if module == 'drug_classification':
        return onkopus.onkopus_clients.DrugOnClient(genome_version=genome_version)
    if module == 'all':
        return onkopus.onkopus_clients.AllModulesClient(genome_version=genome_version)
    if module == 'liftover':
        client = adagenes.LiftoverClient(genome_version=genome_version)
        client.target_genome = target
        return client
    if module == 'liftover_annotation':
        return adagenes.LiftoverAnnotationClient(genome_version=genome_version)

    return None


def get_lo_targets(genome_version):
    targets = []

    if genome_version == "hg19":
        targets = ["hg38", "t2t"]
    elif genome_version == "hg38":
        targets = ["hg19","t2t"]
    elif genome_version == "t2t":
        targets = ["hg19","hg38"]

    return targets


def annotate_variant_data(
                          annotated_data,
                          genome_version: str = 'hg38',
                          module=None,
                          oncokb_key='',
                          lo_hg19=None,
                          lo_hg38=None,
                          lo_t2t=None,
                          tumor_type=None
                          ):
    """
    Retrieves all annotation modules for a list of variants and returns an annotated JSON representation of the annotated variants

    Parameters
    ----------
    vcf_data

    Returns
    -------

    """
    if module is None:
        modules = conf_reader.__ACTIVE_MODULES__
    else:
        modules = [module]

    if annotated_data is None:
        return {}

    #if 'liftover' in modules:
    #    lo_targets = get_lo_targets(genome_version)
    #    for target in lo_targets:
    #        client = adagenes.LiftoverAnnotationClient(genome_version=genome_version)
    #        annotated_data = client.process_data(annotated_data, lo_hg19=lo_hg19, lo_hg38=lo_hg38, lo_t2t=lo_t2t, target_genome=target)
    #    genome_version="hg38"

    if (genome_version=="hg19") or (genome_version=="t2t"):
        annotated_data = onkopus.LiftOverClient(genome_version=genome_version, target_genome="hg38")
        print("Converted data to GRCh38")

    if 'ccs' in modules:
        annotated_data = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version).process_data(annotated_data)

    annotated_data = onkopus.onkopus_clients.CCSGeneToGenomicClient(genome_version=genome_version).process_data(annotated_data, data_type="g")

    # Parallelized annotation requests
    if "revel" in modules:
        annotated_data = parallel_requests(annotated_data, genome_version, oncokb_key=oncokb_key)

    # Parallelized interpretation requests
    if "aggregator" in modules:
        #print("agg start")
        annotated_data = parallel_interpreter_requests(annotated_data,genome_version)
        #print("agg ok")
        if isinstance(annotated_data, str):
            annotated_data = json.loads(annotated_data)

    annotated_data = onkopus.onkopus_clients.InterpreterClient(genome_version=genome_version).process_data(annotated_data, tumor_type=tumor_type)
    if isinstance(annotated_data, str):
        print(annotated_data)
        try:
            annotated_data = json.loads(annotated_data)
        except:
            print(traceback.format_exc())

    if 'biomarker_types' in modules:
        annotated_data = onkopus.onkopus_clients.BiomarkerRecognitionClient(
            genome_version=genome_version).process_data(annotated_data)
    #if 'drug_classification' in modules:
    #    annotated_data = onkopus.onkopus_clients.DrugOnClient(
    #        genome_version=genome_version).process_data(annotated_data)

    return annotated_data



def annotate_file_all_modules(
                              infile_str,
                              outfile_str,
                              genome_version='hg38',
                              reader_input_format=None,
                              writer_output_format=None
                              ):
    """
    Annotates a specified file and writes the annotated file in the specified output path

    :param infile_str:
    :param outfile_str:
    :param genome_version:
    :param reader_input_format:
    :param writer_output_format:
    :return:
    """
    # generate reader
    reader = adagenes.tools.get_reader(infile_str, file_type=reader_input_format)
    writer = adagenes.tools.get_writer(outfile_str, file_type=writer_output_format)

    json_obj = reader.read_file(infile_str)
    annotated_data = json_obj.data

    #variant_dc = adagenes.generate_variant_dictionary(annotated_data)

    if 'ccs_liftover' in conf_reader.__ACTIVE_MODULES__:
        client = onkopus.onkopus_clients.ccs_liftover_client.LiftOverClient(genome_version=genome_version)
        annotated_data = client.process_data(annotated_data)
    if 'ccs' in conf_reader.__ACTIVE_MODULES__:
        client = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version)
        annotated_data = client.process_data(annotated_data)
    if 'dbsnp' in conf_reader.__ACTIVE_MODULES__:
        client = onkopus.onkopus_clients.DBSNPClient(genome_version=genome_version)
        annotated_data = client.process_data(annotated_data)
    if 'clinvar' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.ClinVarClient(genome_version=genome_version).process_data(
            annotated_data)
    if 'revel' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.revel_client.REVELClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'loftool' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.LoFToolClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'vuspredict' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.VUSPredictClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'metakb' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.MetaKBClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'mvp' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.MVPClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'primateai' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.PrimateAIClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'alphamissense' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.AlphaMissenseClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'dbnsfp' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.DBNSFPClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'gencode' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.GENCODEClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'gencode_genomic' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.GENCODEGenomicClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'uta_adapter_protein_sequence' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(genome_version=genome_version).process_data(annotated_data)
    if 'civic' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.CIViCClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'oncokb' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.OncoKBClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'aggregator' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.AggregatorClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'biomarker_types' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.BiomarkerRecognitionClient(
            genome_version=genome_version).process_data(annotated_data)
    if 'drug_classification' in conf_reader.__ACTIVE_MODULES__:
        annotated_data = onkopus.onkopus_clients.DrugOnClient(
            genome_version=genome_version).process_data(annotated_data)

    json_obj.data = annotated_data
    writer.write_to_file(outfile_str, json_obj, )


def annotate_file(infile_str, outfile_str, module, genome_version, lo_hg19=None,lo_hg38=None):
    """
    Annotates a biomarker file with an Onkopus client
    
    :param infile_str:
    :param outfile_str:
    :param module:
    :param genome_version:
    :return:
    """
    infile = adagenes.open_infile(infile_str)
    outfile = adagenes.open_outfile(outfile_str)

    if module == "uta":
        vcf_obj = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version)
    elif module == "uta_gene":
        vcf_obj = onkopus.onkopus_clients.ccs_genomic_client.CCSGeneToGenomicClient(
                genome_version=genome_version)
    elif module == 'ccs_liftover':
        vcf_obj = onkopus.onkopus_clients.LiftOverClient(genome_version=genome_version)
    elif module == 'liftover':
        vcf_obj = onkopus.LiftoverAnnotationClient(genome_version)
    elif module == 'dbsnp':
        vcf_obj = onkopus.onkopus_clients.DBSNPClient(genome_version=genome_version)
    elif module == "clinvar":
        vcf_obj = onkopus.onkopus_clients.ClinVarClient(genome_version=genome_version)
    elif module == "revel":
        vcf_obj = onkopus.onkopus_clients.REVELClient(genome_version=genome_version)
    elif module == "loftool":
        vcf_obj = onkopus.onkopus_clients.LoFToolClient(genome_version=genome_version)
    elif module == "vuspredict":
        vcf_obj = onkopus.onkopus_clients.VUSPredictClient(genome_version=genome_version)
    elif module == 'metakb':
        vcf_obj = onkopus.onkopus_clients.MetaKBClient(genome_version=genome_version)
    elif module == 'mvp':
        vcf_obj = onkopus.onkopus_clients.MVPClient(genome_version=genome_version)
    elif module == 'primateai':
        vcf_obj = onkopus.onkopus_clients.PrimateAIClient(genome_version=genome_version)
    elif module == 'alphamissense':
        vcf_obj = onkopus.onkopus_clients.AlphaMissenseClient(genome_version=genome_version)
    elif module == 'dbnsfp':
        vcf_obj = onkopus.onkopus_clients.DBNSFPClient(genome_version=genome_version)
    elif module == 'gencode':
        vcf_obj = onkopus.onkopus_clients.GENCODEClient(
                genome_version=genome_version)
    elif module == 'gencode_genomic':
        vcf_obj = onkopus.onkopus_clients.GENCODEGenomicClient(
                genome_version=genome_version)
    elif module == 'uta_adapter_protein_sequence':
        vcf_obj = onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(genome_version=genome_version)
    elif module == 'civic':
        vcf_obj = onkopus.onkopus_clients.CIViCClient(genome_version=genome_version)
    elif module == 'oncokb':
        vcf_obj = onkopus.onkopus_clients.OncoKBClient(genome_version=genome_version)
    elif module == 'aggregator':
        vcf_obj = onkopus.onkopus_clients.AggregatorClient(genome_version=genome_version)
    elif module == 'biomarker_types':
        vcf_obj = onkopus.onkopus_clients.BiomarkerRecognitionClient(genome_version=genome_version)
    elif module == 'drug_classification':
        vcf_obj  = onkopus.onkopus_clients.DrugOnClient(genome_version=genome_version)
    elif module == 'all':
        vcf_obj = onkopus.onkopus_clients.AllModulesClient(genome_version=genome_version)

    print("perform analysis (", module, "), infile ", infile_str, " output in ", outfile_str)
    if module == 'liftover':
        adagenes.processing.process_files.process_file(infile_str, outfile_str, vcf_obj, genome_version=genome_version,
                                                     input_format='json',
                                                     output_format='json',
                                                     lo_hg19=lo_hg19,lo_hg38=lo_hg38)
    else:
        adagenes.processing.process_files.process_file(infile_str, outfile_str, vcf_obj, genome_version=genome_version, input_format='json',
                          output_format='json')

    infile.close()
    outfile.close()


def annotate_file_db(variant_data,module, genome_version, lo_hg19=None, lo_hg38=None):
    """
    Annotates a biomarker file with an Onkopus client

    :param module:
    :param genome_version:
    :return:
    """

    vcf_obj = None
    if module == "UTA_Adapter":
        vcf_obj = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version)
    elif module == "UTA_Adapter_gene":
        vcf_obj = onkopus.onkopus_clients.ccs_genomic_client.CCSGeneToGenomicClient(
            genome_version=genome_version)
    elif module == 'ccs_liftover':
        vcf_obj = onkopus.onkopus_clients.LiftOverClient(genome_version=genome_version)
    elif module == 'liftover':
        vcf_obj = adagenes.LiftoverAnnotationClient(genome_version)
    elif module == 'dbsnp':
        vcf_obj = onkopus.onkopus_clients.DBSNPClient(genome_version=genome_version)
    elif module == "clinvar":
        vcf_obj = onkopus.onkopus_clients.ClinVarClient(genome_version=genome_version)
    elif module == "revel":
        vcf_obj = onkopus.onkopus_clients.REVELClient(genome_version=genome_version)
    elif module == "loftool":
        vcf_obj = onkopus.onkopus_clients.LoFToolClient(genome_version=genome_version)
    elif module == "vus_predict":
        vcf_obj = onkopus.onkopus_clients.VUSPredictClient(genome_version=genome_version)
    elif module == "vuspredict":
        vcf_obj = onkopus.onkopus_clients.VUSPredictClient(genome_version=genome_version)
    elif module == 'metakb':
        vcf_obj = onkopus.onkopus_clients.MetaKBClient(genome_version=genome_version)
    elif module == 'mvp':
        vcf_obj = onkopus.onkopus_clients.MVPClient(genome_version=genome_version)
    elif module == 'primateai':
        vcf_obj = onkopus.onkopus_clients.PrimateAIClient(genome_version=genome_version)
    elif module == 'alphamissense':
        vcf_obj = onkopus.onkopus_clients.AlphaMissenseClient(genome_version=genome_version)
    elif module == 'dbnsfp':
        vcf_obj = onkopus.onkopus_clients.DBNSFPClient(genome_version=genome_version)
    elif module == 'gencode':
        vcf_obj = onkopus.onkopus_clients.GENCODEClient(
            genome_version=genome_version)
    elif module == 'gencode_genomic':
        vcf_obj = onkopus.onkopus_clients.GENCODEGenomicClient(
            genome_version=genome_version)
    elif module == 'UTA_Adapter_protein_sequence':
        vcf_obj = onkopus.onkopus_clients.UTAAdapterProteinSequenceClient(genome_version=genome_version)
    elif module == 'civic':
        vcf_obj = onkopus.onkopus_clients.CIViCClient(genome_version=genome_version)
    elif module == 'oncokb':
        vcf_obj = onkopus.onkopus_clients.OncoKBClient(genome_version=genome_version)
    elif module == 'onkopus_aggregator':
        vcf_obj = onkopus.onkopus_clients.AggregatorClient(genome_version=genome_version)
    elif module == 'biomarker_types':
        vcf_obj = onkopus.onkopus_clients.BiomarkerRecognitionClient(genome_version=genome_version)
    elif module == 'drug_classification':
        vcf_obj = onkopus.onkopus_clients.DrugOnClient(genome_version=genome_version)
    elif module == 'all':
        vcf_obj = onkopus.onkopus_clients.AllModulesClient(genome_version=genome_version)

    if module == 'liftover':
        variant_data = vcf_obj.process_data(variant_data,lo_hg19=lo_hg19, lo_hg38=lo_hg38)
    else:
        if vcf_obj is not None:
            variant_data = vcf_obj.process_data(variant_data)
        else:
            print("Error: No client instantiated: ",module)

    return variant_data




import datetime, traceback, copy
import adagenes.tools
import adagenes.tools.module_requests as req
from onkopus.conf import read_config as config


class GENCODEGeneNameClient:
    def __init__(self, genome_version, error_logfile=None):
        self.genome_version = genome_version
        self.url_pattern = config.gencode_src
        self.srv_prefix = config.gencode_srv_prefix
        self.extract_keys = config.gencode_keys
        self.info_lines = config.gencode_info_lines
        self.error_logfile = error_logfile

        self.qid_key = "q_id"
        if (self.genome_version == "hg19") or (self.genome_version == "GRCh37"):
            self.qid_key = "q_id_hg19"

    def process_data(self, vcf_lines, input_format='json'):

        if input_format == 'vcf':
            keys = [config.uta_adapter_srv_prefix + config.concat_char + config.uta_genomic_keys[0]]
            annotations = adagenes.tools.parse_vcf.extract_annotations_vcf(vcf_lines, keys)
        else:
            keys = [config.uta_genomic_keys[0]]
            annotations = adagenes.tools.parse_vcf.extract_annotations_json(vcf_lines, config.uta_adapter_srv_prefix, keys)

        qid_list = list(vcf_lines.keys())

        while True:
            max_length = int(config.config["DEFAULT"]["MODULE_BATCH_SIZE"])
            if max_length > len(qid_list):
                max_length = len(qid_list)
            qids_partial = qid_list[0:max_length]
            qids_partial = adagenes.tools.filter_alternate_alleles(qids_partial)
            genompos_str = ','.join(qids_partial)
            gene_names_partial = list(vcf_lines.keys())
            gene_names_str = ",".join(gene_names_partial)
            query = 'genes=' + gene_names_str
            query = '?' + query + '&response_type=grouped'
            #dc = adagenes.tools.parse_genomic_data.generate_dictionary(gene_names_partial,qids_partial)

            try:
                json_body = req.get_connection(query, self.url_pattern, "hg38")

                for gene_name in json_body.keys():

                        qid = gene_name#dc[gene_name]

                        try:
                            vcf_lines[qid][self.srv_prefix] = json_body[gene_name]
                        except:
                            if self.error_logfile is not None:
                                cur_dt = datetime.datetime.now()
                                date_time = cur_dt.strftime("%m/%d/%Y, %H:%M:%S")
                                print(cur_dt, ": error processing variant response: ", qid, ';', traceback.format_exc(), file=self.error_logfile+str(date_time)+'.log')
                            else:
                                print(cur_dt, ": error processing variant response: ", qid, ';', traceback.format_exc())
            except:
                print(": error processing variant response: ;", traceback.format_exc())
                if self.error_logfile is not None:
                    print("error processing request: ", annotations, file=self.error_logfile+str(date_time)+'.log')

            for i in range(0,max_length):
                del qid_list[0]
            if len(qid_list) == 0:
                break

        return vcf_lines



import unittest, os
import adagenes
import onkopus as op


class TestProteinToGenomic(unittest.TestCase):

    def test_protein_to_genomic(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        infile = __location__ + "/../test_files/tp53_mutations.csv"
        bframe = adagenes.read_file(infile, genome_version="hg38")

        print("read ",bframe.data)
        bframe = op.ProteinToGenomic().process_data(bframe)

        print(bframe.data.keys())
        qids = ['chr17:7676591C>T', 'chr17:7676591C>G', 'chr17:7676590T>G', 'chr17:7676590T>C', 'chr17:7676589C>A', 'chr17:7676588C>T', 'chr17:7676588C>G', 'chr17:7676587T>G', 'chr17:7676587T>C', 'chr17:7676587T>A', 'chr17:7676586C>A', 'chr17:7676585G>T']
        self.assertListEqual(list(bframe.data.keys()),qids,"Error protein to genomic")




import unittest
import onkopus.onkopus_clients


class CIViCGeneTestCase(unittest.TestCase):

    def test_civic_client(self):
        genome_version = 'hg19'

        data = {"KRAS": {}, "TP53": {}}

        variant_data = onkopus.onkopus_clients.CIViCGeneClient(
            genome_version=genome_version).process_data(data)

        print("Response ",variant_data)



import unittest, os
import onkopus.onkopus_clients

class CIViCAnnotationTestCase(unittest.TestCase):

    def test_civic_client(self):
        genome_version = 'hg19'

        data = {"chr17:7681744T>C": {}, "chr10:8115913C>T": {}}

        variant_data = onkopus.onkopus_clients.ClinVarClient(
            genome_version=genome_version).process_data(data)

        print("Response ",variant_data)

    def test_civic_client_batch(self):
        __location__ = os.path.realpath(
            os.path.join(os.getcwd(), os.path.dirname(__file__)))
        genome_version = 'hg38'
        file= __location__ + '/../../test_files/somaticMutations.vcf'

        data = onkopus.read_file(file)

        data.data = onkopus.onkopus_clients.UTAAdapterClient(genome_version=genome_version).process_data(data.data)

        data.data = onkopus.onkopus_clients.CIViCClient(
            genome_version=genome_version).process_data(data.data)

        print(data.data)
